@@ -477,7 +477,7 @@ def get_changes_submitted_together(rest, changeid):
             raise RuntimeError(f"Provided change ({changeid}) cannot be found on remote gerrit server.")
 
 
-def _get_payload(payload_json, path_prefixes, robot_id, robot_run_id):
+def _get_payload(git_repo, payload_json, path_prefixes, robot_id, robot_run_id):
     def trim_prefixes(name, prefixes):
         for prefix in prefixes:
             name = name.lstrip(prefix)
@@ -501,6 +501,10 @@ def _get_payload(payload_json, path_prefixes, robot_id, robot_run_id):
     comments = payload["comments"].copy()
     payload["robot_comments"] = {}
     for key in comments:
+        if not key.startswith(git_repo.working_dir): ## TODO: if compiledb doesnt have absolute paths, this most likely will fail, fix later
+            LOGGER.debug(f"File {key} contains issues reported by static analysis but its not part of the git repository at {git_repo.working_dir} - Skipping!")
+            continue
+
         new_key = trim_prefixes(key, prefixes)
         for item in comments[key]:
             item["robot_id"] = "clang-tidy"
@@ -537,7 +541,7 @@ def review(rest, git_repo, args, gerrit_config):
 
     change_details = get_change_detail(rest, args.changeid)
     rev = get_rev(change_details)
-    payload = _get_payload(args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
+    payload = _get_payload(git_repo, args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
     payload["omit_duplicate_comments"] = True
     payload["notify"] = "OWNER"
 
